<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl" sourcelanguage="en">
<context>
    <name>ActionShowStashDelegate</name>
    <message>
        <source>Application tray</source>
        <translation>Zasobnik aplikacji</translation>
    </message>
</context>
<context>
    <name>ActionToggleCollapseDelegate</name>
    <message>
        <source>Collapse tray</source>
        <translation>Zwiń zasobnik</translation>
    </message>
</context>
<context>
    <name>PanelTrayItem</name>
    <message>
        <source>Quick actions</source>
        <translation>Szybkie akcje</translation>
    </message>
</context>
</TS>